summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulien Nabet <serval2412@yahoo.fr>2014-10-12 13:00:46 +0200
committerJulien Nabet <serval2412@yahoo.fr>2014-10-12 13:00:46 +0200
commit4c12951a0304d257a6b0e6b5aa2ecbbe60393c8d (patch)
tree8d03b1ff605f0bf3b3f618ef969e064c66fbbf22
parentd0d64225d853d01bf601b3738c26fd8ada41650e (diff)
Typo: compatability->compatibility
Change-Id: If0b98a30452a9d1fcc340173deb6856755926471
-rw-r--r--basic/source/runtime/stdobj.cxx2
-rw-r--r--external/unixODBC/inc/odbc/sqltypes.h2
-rw-r--r--include/filter/msfilter/msocximex.hxx2
-rw-r--r--sw/inc/doc.hxx4
-rw-r--r--sw/source/core/doc/docnew.cxx4
-rw-r--r--sw/source/core/inc/DocumentSettingManager.hxx2
-rw-r--r--sw/source/filter/ww8/wrtww8.cxx6
-rw-r--r--sw/source/filter/ww8/ww8par.cxx6
-rw-r--r--sw/source/filter/ww8/ww8scan.cxx200
-rw-r--r--sw/source/filter/ww8/ww8scan.hxx100
-rw-r--r--sw/source/ui/dbui/mmoutputpage.cxx4
-rw-r--r--sw/source/uibase/dbui/dbmgr.cxx2
-rw-r--r--sw/source/uibase/dochdl/swdtflvr.cxx2
-rw-r--r--writerfilter/source/dmapper/PropertyMap.cxx2
14 files changed, 169 insertions, 169 deletions
diff --git a/basic/source/runtime/stdobj.cxx b/basic/source/runtime/stdobj.cxx
index 6550157cc55b..664d76c887ac 100644
--- a/basic/source/runtime/stdobj.cxx
+++ b/basic/source/runtime/stdobj.cxx
@@ -37,7 +37,7 @@
// allow us space for a flag to blacklist some functions in vba mode
#define _ARGSMASK 0x003F // 63 Arguments
-#define _COMPTMASK 0x00C0 // COMPATABILITY mask
+#define _COMPTMASK 0x00C0 // COMPATIBILITY mask
#define _COMPATONLY 0x0080 // procedure is visible in vba mode only
#define _NORMONLY 0x0040 // procedure is visible in normal mode only
diff --git a/external/unixODBC/inc/odbc/sqltypes.h b/external/unixODBC/inc/odbc/sqltypes.h
index 9e05bc34476f..5cadacb4c359 100644
--- a/external/unixODBC/inc/odbc/sqltypes.h
+++ b/external/unixODBC/inc/odbc/sqltypes.h
@@ -4,7 +4,7 @@
* This is the lowest level include in unixODBC. It defines
* the basic types required by unixODBC and is heavily based
* upon the MS include of the same name (it has to be for
- * binary compatability between drivers developed under different
+ * binary compatibility between drivers developed under different
* packages).
*
* You can include this file directly but it is almost always
diff --git a/include/filter/msfilter/msocximex.hxx b/include/filter/msfilter/msocximex.hxx
index c3877d721d85..caa91f748893 100644
--- a/include/filter/msfilter/msocximex.hxx
+++ b/include/filter/msfilter/msocximex.hxx
@@ -74,7 +74,7 @@ public:
com::sun::star::drawing::XShape >* /*pShape*/,
bool /*bFloatingCtrl*/ ) {return false;}
- /*begin: Backwards compatability with office 95 import, modify later*/
+ /*begin: Backwards compatibility with office 95 import, modify later*/
const com::sun::star::uno::Reference<
com::sun::star::lang::XMultiServiceFactory > & GetServiceFactory();
protected:
diff --git a/sw/source/core/doc/docnew.cxx b/sw/source/core/doc/docnew.cxx
index 710db732352a..0ba8fb269b4b 100644
--- a/sw/source/core/doc/docnew.cxx
+++ b/sw/source/core/doc/docnew.cxx
@@ -877,7 +877,7 @@ void SwDoc::ReplaceDefaults(const SwDoc& rSource)
SetDefault(aNewDefaults);
}
-void SwDoc::ReplaceCompatabilityOptions(const SwDoc& rSource)
+void SwDoc::ReplaceCompatibilityOptions(const SwDoc& rSource)
{
m_pDocumentSettingManager->ReplaceCompatibilityOptions(rSource.GetDocumentSettingManager());
}
@@ -908,7 +908,7 @@ SfxObjectShell* SwDoc::CreateCopy(bool bCallInitNew ) const
pRet->ReplaceDefaults(*this);
- pRet->ReplaceCompatabilityOptions(*this);
+ pRet->ReplaceCompatibilityOptions(*this);
pRet->ReplaceStyles(*this);
diff --git a/sw/source/core/inc/DocumentSettingManager.hxx b/sw/source/core/inc/DocumentSettingManager.hxx
index 252d126dcd72..66cc76cc899c 100644
--- a/sw/source/core/inc/DocumentSettingManager.hxx
+++ b/sw/source/core/inc/DocumentSettingManager.hxx
@@ -171,7 +171,7 @@ public:
virtual void setCharacterCompressionType( /*[in]*/SwCharCompressType nType ) SAL_OVERRIDE;
-// Replace all compatability options with those from rSource.
+// Replace all compatibility options with those from rSource.
void ReplaceCompatibilityOptions(const DocumentSettingManager& rSource);
sal_uInt32 Getn32DummyCompatibilityOptions1() const SAL_OVERRIDE;
diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index 64e86d00a771..1d271f7dd7fe 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -323,9 +323,9 @@ static void WriteDop( WW8Export& rWrt )
{
WW8Dop& rDop = *rWrt.pDop;
- // i#78951#, store the value of unknown compatability options
- rDop.SetCompatabilityOptions( rWrt.pDoc->getIDocumentSettingAccess().Getn32DummyCompatibilityOptions1());
- rDop.SetCompatabilityOptions2( rWrt.pDoc->getIDocumentSettingAccess().Getn32DummyCompatibilityOptions2());
+ // i#78951#, store the value of unknown compatibility options
+ rDop.SetCompatibilityOptions( rWrt.pDoc->getIDocumentSettingAccess().Getn32DummyCompatibilityOptions1());
+ rDop.SetCompatibilityOptions2( rWrt.pDoc->getIDocumentSettingAccess().Getn32DummyCompatibilityOptions2());
rDop.fNoLeading = !rWrt.pDoc->getIDocumentSettingAccess().get(IDocumentSettingAccess::ADD_EXT_LEADING);
rDop.fUsePrinterMetrics = !rWrt.pDoc->getIDocumentSettingAccess().get(IDocumentSettingAccess::USE_VIRTUAL_DEVICE);
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index df76c200920d..7b96f8537e75 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -1847,8 +1847,8 @@ void SwWW8ImplReader::ImportDop()
// #i78951# - remember the unknown compatibility options
// so as to export them out
- rDoc.getIDocumentSettingAccess().Setn32DummyCompatibilityOptions1( pWDop->GetCompatabilityOptions());
- rDoc.getIDocumentSettingAccess().Setn32DummyCompatibilityOptions2( pWDop->GetCompatabilityOptions2());
+ rDoc.getIDocumentSettingAccess().Setn32DummyCompatibilityOptions1( pWDop->GetCompatibilityOptions());
+ rDoc.getIDocumentSettingAccess().Setn32DummyCompatibilityOptions2( pWDop->GetCompatibilityOptions2());
// The distance between two paragraphs is the sum of the bottom distance of
// the first paragraph and the top distance of the second one
@@ -4633,7 +4633,7 @@ void wwSectionManager::InsertSegments()
// The last section if continuous is always unbalanced
if (pRet)
{
- // Set the columns to be UnBalanced if that compatability option is set
+ // Set the columns to be UnBalanced if that compatibility option is set
if (mrReader.pWDop->fNoColumnBalance)
pRet->SetFmtAttr(SwFmtNoBalancedColumns(true));
else
diff --git a/sw/source/filter/ww8/ww8scan.cxx b/sw/source/filter/ww8/ww8scan.cxx
index 9c3d2665bae0..f37715eb1e18 100644
--- a/sw/source/filter/ww8/ww8scan.cxx
+++ b/sw/source/filter/ww8/ww8scan.cxx
@@ -6647,7 +6647,7 @@ WW8Dop::WW8Dop(SvStream& rSt, sal_Int16 nFib, sal_Int32 nPos, sal_uInt32 nSize)
if (nFib >= 103) // Word 6/32bit, 95, 97, 2000, 2002, 2003, 2007
{
a32Bit = Get_ULong( pData ); // 84 0x54
- SetCompatabilityOptions(a32Bit);
+ SetCompatibilityOptions(a32Bit);
}
//#i22436#, for all WW7- documents
@@ -6702,11 +6702,11 @@ WW8Dop::WW8Dop(SvStream& rSt, sal_Int16 nFib, sal_Int32 nPos, sal_uInt32 nSize)
//500 -> 508, Appear to be repeated here in 2000+
pData += 8; // 500 0x1f4
a32Bit = Get_Long( pData ); // 508 0x1fc
- SetCompatabilityOptions(a32Bit);
+ SetCompatibilityOptions(a32Bit);
a32Bit = Get_Long( pData ); // 512 0x200
// i#78591#
- SetCompatabilityOptions2(a32Bit);
+ SetCompatibilityOptions2(a32Bit);
}
if (nRead >= 550)
{
@@ -6789,7 +6789,7 @@ WW8Dop::WW8Dop()
fAcetateShowAtn = true;
}
-void WW8Dop::SetCompatabilityOptions(sal_uInt32 a32Bit)
+void WW8Dop::SetCompatibilityOptions(sal_uInt32 a32Bit)
{
fNoTabForInd = ( a32Bit & 0x00000001 ) ;
fNoSpaceRaiseLower = ( a32Bit & 0x00000002 ) >> 1 ;
@@ -6803,30 +6803,30 @@ void WW8Dop::SetCompatabilityOptions(sal_uInt32 a32Bit)
fTransparentMetafiles = ( a32Bit & 0x00000200 ) >> 9 ;
fShowBreaksInFrames = ( a32Bit & 0x00000400 ) >> 10 ;
fSwapBordersFacingPgs = ( a32Bit & 0x00000800 ) >> 11 ;
- fCompatabilityOptions_Unknown1_13 = ( a32Bit & 0x00001000 ) >> 12 ;
+ fCompatibilityOptions_Unknown1_13 = ( a32Bit & 0x00001000 ) >> 12 ;
fExpShRtn = ( a32Bit & 0x00002000 ) >> 13 ; // #i56856#
- fCompatabilityOptions_Unknown1_15 = ( a32Bit & 0x00004000 ) >> 14 ;
- fCompatabilityOptions_Unknown1_16 = ( a32Bit & 0x00008000 ) >> 15 ;
+ fCompatibilityOptions_Unknown1_15 = ( a32Bit & 0x00004000 ) >> 14 ;
+ fCompatibilityOptions_Unknown1_16 = ( a32Bit & 0x00008000 ) >> 15 ;
fSuppressTopSpacingMac5 = ( a32Bit & 0x00010000 ) >> 16 ;
fTruncDxaExpand = ( a32Bit & 0x00020000 ) >> 17 ;
fPrintBodyBeforeHdr = ( a32Bit & 0x00040000 ) >> 18 ;
fNoLeading = ( a32Bit & 0x00080000 ) >> 19 ;
- fCompatabilityOptions_Unknown1_21 = ( a32Bit & 0x00100000 ) >> 20 ;
+ fCompatibilityOptions_Unknown1_21 = ( a32Bit & 0x00100000 ) >> 20 ;
fMWSmallCaps = ( a32Bit & 0x00200000 ) >> 21 ;
- fCompatabilityOptions_Unknown1_23 = ( a32Bit & 0x00400000 ) >> 22 ;
- fCompatabilityOptions_Unknown1_24 = ( a32Bit & 0x00800800 ) >> 23 ;
- fCompatabilityOptions_Unknown1_25 = ( a32Bit & 0x01000000 ) >> 24 ;
- fCompatabilityOptions_Unknown1_26 = ( a32Bit & 0x02000000 ) >> 25 ;
- fCompatabilityOptions_Unknown1_27 = ( a32Bit & 0x04000000 ) >> 26 ;
- fCompatabilityOptions_Unknown1_28 = ( a32Bit & 0x08000000 ) >> 27 ;
- fCompatabilityOptions_Unknown1_29 = ( a32Bit & 0x10000000 ) >> 28 ;
- fCompatabilityOptions_Unknown1_30 = ( a32Bit & 0x20000000 ) >> 29 ;
- fCompatabilityOptions_Unknown1_31 = ( a32Bit & 0x40000000 ) >> 30 ;
+ fCompatibilityOptions_Unknown1_23 = ( a32Bit & 0x00400000 ) >> 22 ;
+ fCompatibilityOptions_Unknown1_24 = ( a32Bit & 0x00800800 ) >> 23 ;
+ fCompatibilityOptions_Unknown1_25 = ( a32Bit & 0x01000000 ) >> 24 ;
+ fCompatibilityOptions_Unknown1_26 = ( a32Bit & 0x02000000 ) >> 25 ;
+ fCompatibilityOptions_Unknown1_27 = ( a32Bit & 0x04000000 ) >> 26 ;
+ fCompatibilityOptions_Unknown1_28 = ( a32Bit & 0x08000000 ) >> 27 ;
+ fCompatibilityOptions_Unknown1_29 = ( a32Bit & 0x10000000 ) >> 28 ;
+ fCompatibilityOptions_Unknown1_30 = ( a32Bit & 0x20000000 ) >> 29 ;
+ fCompatibilityOptions_Unknown1_31 = ( a32Bit & 0x40000000 ) >> 30 ;
fUsePrinterMetrics = ( a32Bit & 0x80000000 ) >> 31 ;
}
-sal_uInt32 WW8Dop::GetCompatabilityOptions() const
+sal_uInt32 WW8Dop::GetCompatibilityOptions() const
{
sal_uInt32 a32Bit = 0;
if (fNoTabForInd) a32Bit |= 0x00000001;
@@ -6841,105 +6841,105 @@ sal_uInt32 WW8Dop::GetCompatabilityOptions() const
if (fTransparentMetafiles) a32Bit |= 0x00000200;
if (fShowBreaksInFrames) a32Bit |= 0x00000400;
if (fSwapBordersFacingPgs) a32Bit |= 0x00000800;
- if (fCompatabilityOptions_Unknown1_13) a32Bit |= 0x00001000;
+ if (fCompatibilityOptions_Unknown1_13) a32Bit |= 0x00001000;
if (fExpShRtn) a32Bit |= 0x00002000; // #i56856#
- if (fCompatabilityOptions_Unknown1_15) a32Bit |= 0x00004000;
- if (fCompatabilityOptions_Unknown1_16) a32Bit |= 0x00008000;
+ if (fCompatibilityOptions_Unknown1_15) a32Bit |= 0x00004000;
+ if (fCompatibilityOptions_Unknown1_16) a32Bit |= 0x00008000;
if (fSuppressTopSpacingMac5) a32Bit |= 0x00010000;
if (fTruncDxaExpand) a32Bit |= 0x00020000;
if (fPrintBodyBeforeHdr) a32Bit |= 0x00040000;
if (fNoLeading) a32Bit |= 0x00080000;
- if (fCompatabilityOptions_Unknown1_21) a32Bit |= 0x00100000;
+ if (fCompatibilityOptions_Unknown1_21) a32Bit |= 0x00100000;
if (fMWSmallCaps) a32Bit |= 0x00200000;
- if (fCompatabilityOptions_Unknown1_23) a32Bit |= 0x00400000;
- if (fCompatabilityOptions_Unknown1_24) a32Bit |= 0x00800000;
- if (fCompatabilityOptions_Unknown1_25) a32Bit |= 0x01000000;
- if (fCompatabilityOptions_Unknown1_26) a32Bit |= 0x02000000;
- if (fCompatabilityOptions_Unknown1_27) a32Bit |= 0x04000000;
- if (fCompatabilityOptions_Unknown1_28) a32Bit |= 0x08000000;
- if (fCompatabilityOptions_Unknown1_29) a32Bit |= 0x10000000;
- if (fCompatabilityOptions_Unknown1_30) a32Bit |= 0x20000000;
- if (fCompatabilityOptions_Unknown1_31) a32Bit |= 0x40000000;
+ if (fCompatibilityOptions_Unknown1_23) a32Bit |= 0x00400000;
+ if (fCompatibilityOptions_Unknown1_24) a32Bit |= 0x00800000;
+ if (fCompatibilityOptions_Unknown1_25) a32Bit |= 0x01000000;
+ if (fCompatibilityOptions_Unknown1_26) a32Bit |= 0x02000000;
+ if (fCompatibilityOptions_Unknown1_27) a32Bit |= 0x04000000;
+ if (fCompatibilityOptions_Unknown1_28) a32Bit |= 0x08000000;
+ if (fCompatibilityOptions_Unknown1_29) a32Bit |= 0x10000000;
+ if (fCompatibilityOptions_Unknown1_30) a32Bit |= 0x20000000;
+ if (fCompatibilityOptions_Unknown1_31) a32Bit |= 0x40000000;
if (fUsePrinterMetrics) a32Bit |= 0x80000000;
return a32Bit;
}
// i#78591#
-void WW8Dop::SetCompatabilityOptions2(sal_uInt32 a32Bit)
+void WW8Dop::SetCompatibilityOptions2(sal_uInt32 a32Bit)
{
- fCompatabilityOptions_Unknown2_1 = ( a32Bit & 0x00000001 );
- fCompatabilityOptions_Unknown2_2 = ( a32Bit & 0x00000002 ) >> 1 ;
+ fCompatibilityOptions_Unknown2_1 = ( a32Bit & 0x00000001 );
+ fCompatibilityOptions_Unknown2_2 = ( a32Bit & 0x00000002 ) >> 1 ;
fDontUseHTMLAutoSpacing = ( a32Bit & 0x00000004 ) >> 2 ;
- fCompatabilityOptions_Unknown2_4 = ( a32Bit & 0x00000008 ) >> 3 ;
- fCompatabilityOptions_Unknown2_5 = ( a32Bit & 0x00000010 ) >> 4 ;
- fCompatabilityOptions_Unknown2_6 = ( a32Bit & 0x00000020 ) >> 5 ;
- fCompatabilityOptions_Unknown2_7 = ( a32Bit & 0x00000040 ) >> 6 ;
- fCompatabilityOptions_Unknown2_8 = ( a32Bit & 0x00000080 ) >> 7 ;
- fCompatabilityOptions_Unknown2_9 = ( a32Bit & 0x00000100 ) >> 8 ;
- fCompatabilityOptions_Unknown2_10 = ( a32Bit & 0x00000200 ) >> 9 ;
- fCompatabilityOptions_Unknown2_11 = ( a32Bit & 0x00000400 ) >> 10 ;
- fCompatabilityOptions_Unknown2_12 = ( a32Bit & 0x00000800 ) >> 11 ;
- fCompatabilityOptions_Unknown2_13 = ( a32Bit & 0x00001000 ) >> 12 ;
- fCompatabilityOptions_Unknown2_14 = ( a32Bit & 0x00002000 ) >> 13 ;
- fCompatabilityOptions_Unknown2_15 = ( a32Bit & 0x00004000 ) >> 14 ;
- fCompatabilityOptions_Unknown2_16 = ( a32Bit & 0x00008000 ) >> 15 ;
- fCompatabilityOptions_Unknown2_17 = ( a32Bit & 0x00010000 ) >> 16 ;
- fCompatabilityOptions_Unknown2_18 = ( a32Bit & 0x00020000 ) >> 17 ;
- fCompatabilityOptions_Unknown2_19 = ( a32Bit & 0x00040000 ) >> 18 ;
- fCompatabilityOptions_Unknown2_20 = ( a32Bit & 0x00080000 ) >> 19 ;
- fCompatabilityOptions_Unknown2_21 = ( a32Bit & 0x00100000 ) >> 20 ;
- fCompatabilityOptions_Unknown2_22 = ( a32Bit & 0x00200000 ) >> 21 ;
- fCompatabilityOptions_Unknown2_23 = ( a32Bit & 0x00400000 ) >> 22 ;
- fCompatabilityOptions_Unknown2_24 = ( a32Bit & 0x00800800 ) >> 23 ;
- fCompatabilityOptions_Unknown2_25 = ( a32Bit & 0x01000800 ) >> 24 ;
- fCompatabilityOptions_Unknown2_26 = ( a32Bit & 0x02000800 ) >> 25 ;
- fCompatabilityOptions_Unknown2_27 = ( a32Bit & 0x04000800 ) >> 26 ;
- fCompatabilityOptions_Unknown2_28 = ( a32Bit & 0x08000800 ) >> 27 ;
- fCompatabilityOptions_Unknown2_29 = ( a32Bit & 0x10000800 ) >> 28 ;
- fCompatabilityOptions_Unknown2_30 = ( a32Bit & 0x20000800 ) >> 29 ;
- fCompatabilityOptions_Unknown2_31 = ( a32Bit & 0x40000800 ) >> 30 ;
- fCompatabilityOptions_Unknown2_32 = ( a32Bit & 0x80000000 ) >> 31 ;
-}
-
-sal_uInt32 WW8Dop::GetCompatabilityOptions2() const
+ fCompatibilityOptions_Unknown2_4 = ( a32Bit & 0x00000008 ) >> 3 ;
+ fCompatibilityOptions_Unknown2_5 = ( a32Bit & 0x00000010 ) >> 4 ;
+ fCompatibilityOptions_Unknown2_6 = ( a32Bit & 0x00000020 ) >> 5 ;
+ fCompatibilityOptions_Unknown2_7 = ( a32Bit & 0x00000040 ) >> 6 ;
+ fCompatibilityOptions_Unknown2_8 = ( a32Bit & 0x00000080 ) >> 7 ;
+ fCompatibilityOptions_Unknown2_9 = ( a32Bit & 0x00000100 ) >> 8 ;
+ fCompatibilityOptions_Unknown2_10 = ( a32Bit & 0x00000200 ) >> 9 ;
+ fCompatibilityOptions_Unknown2_11 = ( a32Bit & 0x00000400 ) >> 10 ;
+ fCompatibilityOptions_Unknown2_12 = ( a32Bit & 0x00000800 ) >> 11 ;
+ fCompatibilityOptions_Unknown2_13 = ( a32Bit & 0x00001000 ) >> 12 ;
+ fCompatibilityOptions_Unknown2_14 = ( a32Bit & 0x00002000 ) >> 13 ;
+ fCompatibilityOptions_Unknown2_15 = ( a32Bit & 0x00004000 ) >> 14 ;
+ fCompatibilityOptions_Unknown2_16 = ( a32Bit & 0x00008000 ) >> 15 ;
+ fCompatibilityOptions_Unknown2_17 = ( a32Bit & 0x00010000 ) >> 16 ;
+ fCompatibilityOptions_Unknown2_18 = ( a32Bit & 0x00020000 ) >> 17 ;
+ fCompatibilityOptions_Unknown2_19 = ( a32Bit & 0x00040000 ) >> 18 ;
+ fCompatibilityOptions_Unknown2_20 = ( a32Bit & 0x00080000 ) >> 19 ;
+ fCompatibilityOptions_Unknown2_21 = ( a32Bit & 0x00100000 ) >> 20 ;
+ fCompatibilityOptions_Unknown2_22 = ( a32Bit & 0x00200000 ) >> 21 ;
+ fCompatibilityOptions_Unknown2_23 = ( a32Bit & 0x00400000 ) >> 22 ;
+ fCompatibilityOptions_Unknown2_24 = ( a32Bit & 0x00800800 ) >> 23 ;
+ fCompatibilityOptions_Unknown2_25 = ( a32Bit & 0x01000800 ) >> 24 ;
+ fCompatibilityOptions_Unknown2_26 = ( a32Bit & 0x02000800 ) >> 25 ;
+ fCompatibilityOptions_Unknown2_27 = ( a32Bit & 0x04000800 ) >> 26 ;
+ fCompatibilityOptions_Unknown2_28 = ( a32Bit & 0x08000800 ) >> 27 ;
+ fCompatibilityOptions_Unknown2_29 = ( a32Bit & 0x10000800 ) >> 28 ;
+ fCompatibilityOptions_Unknown2_30 = ( a32Bit & 0x20000800 ) >> 29 ;
+ fCompatibilityOptions_Unknown2_31 = ( a32Bit & 0x40000800 ) >> 30 ;
+ fCompatibilityOptions_Unknown2_32 = ( a32Bit & 0x80000000 ) >> 31 ;
+}
+
+sal_uInt32 WW8Dop::GetCompatibilityOptions2() const
{
sal_uInt32 a32Bit = 0;
- if (fCompatabilityOptions_Unknown2_1) a32Bit |= 0x00000001;
- if (fCompatabilityOptions_Unknown2_2) a32Bit |= 0x00000002;
+ if (fCompatibilityOptions_Unknown2_1) a32Bit |= 0x00000001;
+ if (fCompatibilityOptions_Unknown2_2) a32Bit |= 0x00000002;
if (fDontUseHTMLAutoSpacing) a32Bit |= 0x00000004;
- if (fCompatabilityOptions_Unknown2_4) a32Bit |= 0x00000008;
- if (fCompatabilityOptions_Unknown2_5) a32Bit |= 0x00000010;
- if (fCompatabilityOptions_Unknown2_6) a32Bit |= 0x00000020;
- if (fCompatabilityOptions_Unknown2_7) a32Bit |= 0x00000040;
- if (fCompatabilityOptions_Unknown2_8) a32Bit |= 0x00000080;
- if (fCompatabilityOptions_Unknown2_9) a32Bit |= 0x00000100;
- if (fCompatabilityOptions_Unknown2_10) a32Bit |= 0x00000200;
- if (fCompatabilityOptions_Unknown2_11) a32Bit |= 0x00000400;
- if (fCompatabilityOptions_Unknown2_12) a32Bit |= 0x00000800;
- if (fCompatabilityOptions_Unknown2_13) a32Bit |= 0x00001000;
+ if (fCompatibilityOptions_Unknown2_4) a32Bit |= 0x00000008;
+ if (fCompatibilityOptions_Unknown2_5) a32Bit |= 0x00000010;
+ if (fCompatibilityOptions_Unknown2_6) a32Bit |= 0x00000020;
+ if (fCompatibilityOptions_Unknown2_7) a32Bit |= 0x00000040;
+ if (fCompatibilityOptions_Unknown2_8) a32Bit |= 0x00000080;
+ if (fCompatibilityOptions_Unknown2_9) a32Bit |= 0x00000100;
+ if (fCompatibilityOptions_Unknown2_10) a32Bit |= 0x00000200;
+ if (fCompatibilityOptions_Unknown2_11) a32Bit |= 0x00000400;
+ if (fCompatibilityOptions_Unknown2_12) a32Bit |= 0x00000800;
+ if (fCompatibilityOptions_Unknown2_13) a32Bit |= 0x00001000;
//#i42909# set thai "line breaking rules" compatibility option
// pflin, wonder whether bUseThaiLineBreakingRules is correct
// when importing word document.
if (bUseThaiLineBreakingRules) a32Bit |= 0x00002000;
- else if (fCompatabilityOptions_Unknown2_14) a32Bit |= 0x00002000;
- if (fCompatabilityOptions_Unknown2_15) a32Bit |= 0x00004000;
- if (fCompatabilityOptions_Unknown2_16) a32Bit |= 0x00008000;
- if (fCompatabilityOptions_Unknown2_17) a32Bit |= 0x00010000;
- if (fCompatabilityOptions_Unknown2_18) a32Bit |= 0x00020000;
- if (fCompatabilityOptions_Unknown2_19) a32Bit |= 0x00040000;
- if (fCompatabilityOptions_Unknown2_20) a32Bit |= 0x00080000;
- if (fCompatabilityOptions_Unknown2_21) a32Bit |= 0x00100000;
- if (fCompatabilityOptions_Unknown2_22) a32Bit |= 0x00200000;
- if (fCompatabilityOptions_Unknown2_23) a32Bit |= 0x00400000;
- if (fCompatabilityOptions_Unknown2_24) a32Bit |= 0x00800000;
- if (fCompatabilityOptions_Unknown2_25) a32Bit |= 0x01000000;
- if (fCompatabilityOptions_Unknown2_26) a32Bit |= 0x02000000;
- if (fCompatabilityOptions_Unknown2_27) a32Bit |= 0x04000000;
- if (fCompatabilityOptions_Unknown2_28) a32Bit |= 0x08000000;
- if (fCompatabilityOptions_Unknown2_29) a32Bit |= 0x10000000;
- if (fCompatabilityOptions_Unknown2_30) a32Bit |= 0x20000000;
- if (fCompatabilityOptions_Unknown2_31) a32Bit |= 0x40000000;
- if (fCompatabilityOptions_Unknown2_32) a32Bit |= 0x80000000;
+ else if (fCompatibilityOptions_Unknown2_14) a32Bit |= 0x00002000;
+ if (fCompatibilityOptions_Unknown2_15) a32Bit |= 0x00004000;
+ if (fCompatibilityOptions_Unknown2_16) a32Bit |= 0x00008000;
+ if (fCompatibilityOptions_Unknown2_17) a32Bit |= 0x00010000;
+ if (fCompatibilityOptions_Unknown2_18) a32Bit |= 0x00020000;
+ if (fCompatibilityOptions_Unknown2_19) a32Bit |= 0x00040000;
+ if (fCompatibilityOptions_Unknown2_20) a32Bit |= 0x00080000;
+ if (fCompatibilityOptions_Unknown2_21) a32Bit |= 0x00100000;
+ if (fCompatibilityOptions_Unknown2_22) a32Bit |= 0x00200000;
+ if (fCompatibilityOptions_Unknown2_23) a32Bit |= 0x00400000;
+ if (fCompatibilityOptions_Unknown2_24) a32Bit |= 0x00800000;
+ if (fCompatibilityOptions_Unknown2_25) a32Bit |= 0x01000000;
+ if (fCompatibilityOptions_Unknown2_26) a32Bit |= 0x02000000;
+ if (fCompatibilityOptions_Unknown2_27) a32Bit |= 0x04000000;
+ if (fCompatibilityOptions_Unknown2_28) a32Bit |= 0x08000000;
+ if (fCompatibilityOptions_Unknown2_29) a32Bit |= 0x10000000;
+ if (fCompatibilityOptions_Unknown2_30) a32Bit |= 0x20000000;
+ if (fCompatibilityOptions_Unknown2_31) a32Bit |= 0x40000000;
+ if (fCompatibilityOptions_Unknown2_32) a32Bit |= 0x80000000;
return a32Bit;
}
@@ -7078,7 +7078,7 @@ bool WW8Dop::Write(SvStream& rStrm, WW8Fib& rFib) const
if( 8 == rFib.nVersion )
{
- Set_UInt32(pData, GetCompatabilityOptions()); // 84 0x54
+ Set_UInt32(pData, GetCompatibilityOptions()); // 84 0x54
Set_UInt16( pData, adt ); // 88 0x58
@@ -7121,8 +7121,8 @@ bool WW8Dop::Write(SvStream& rStrm, WW8Fib& rFib) const
//500 -> 508, Appear to be repeated here in 2000+
pData += 8;
- Set_UInt32(pData, GetCompatabilityOptions());
- Set_UInt32(pData, GetCompatabilityOptions2());
+ Set_UInt32(pData, GetCompatibilityOptions());
+ Set_UInt32(pData, GetCompatibilityOptions2());
pData += 32;
a16Bit = 0;
diff --git a/sw/source/ui/dbui/mmoutputpage.cxx b/sw/source/ui/dbui/mmoutputpage.cxx
index a164ad9640af..17f3b7e384fd 100644
--- a/sw/source/ui/dbui/mmoutputpage.cxx
+++ b/sw/source/ui/dbui/mmoutputpage.cxx
@@ -681,7 +681,7 @@ IMPL_LINK(SwMailMergeOutputPage, SaveOutputHdl_Impl, PushButton*, pButton)
aOpt.SetMerge( false );
pTempView->GetDocShell()->LoadStylesFromFile(
sTargetTempURL, aOpt, true );
- pTempView->GetDocShell()->GetDoc()->ReplaceCompatabilityOptions( *pTargetView->GetDocShell()->GetDoc());
+ pTempView->GetDocShell()->GetDoc()->ReplaceCompatibilityOptions( *pTargetView->GetDocShell()->GetDoc());
pTempView->GetDocShell()->GetDoc()->ReplaceDefaults( *pTargetView->GetDocShell()->GetDoc());
pTempView->GetDocShell()->GetDoc()->ReplaceDocumentProperties( *pTargetView->GetDocShell()->GetDoc(), true );
@@ -1088,7 +1088,7 @@ IMPL_LINK(SwMailMergeOutputPage, SendDocumentsHdl_Impl, PushButton*, pButton)
aOpt.SetMerge( false );
pTempView->GetDocShell()->LoadStylesFromFile(
sTargetTempURL, aOpt, true );
- pTempView->GetDocShell()->GetDoc()->ReplaceCompatabilityOptions( *pTargetView->GetDocShell()->GetDoc());
+ pTempView->GetDocShell()->GetDoc()->ReplaceCompatibilityOptions( *pTargetView->GetDocShell()->GetDoc());
pTempView->GetDocShell()->GetDoc()->ReplaceDefaults( *pTargetView->GetDocShell()->GetDoc());
pTempView->GetDocShell()->GetDoc()->ReplaceDocumentProperties( *pTargetView->GetDocShell()->GetDoc(), true );
pTargetView->GetWrtShell().PastePages(pTempView->GetWrtShell(),
diff --git a/sw/source/uibase/dbui/dbmgr.cxx b/sw/source/uibase/dbui/dbmgr.cxx
index e6475255ba04..f3f9697e1553 100644
--- a/sw/source/uibase/dbui/dbmgr.cxx
+++ b/sw/source/uibase/dbui/dbmgr.cxx
@@ -959,7 +959,7 @@ bool SwDBManager::MergeMailFiles(SwWrtShell* pSourceShell,
rMaster.GetFooter().IsActive();
// copy compatibility options
- pTargetShell->GetDoc()->ReplaceCompatabilityOptions( *pSourceShell->GetDoc());
+ pTargetShell->GetDoc()->ReplaceCompatibilityOptions( *pSourceShell->GetDoc());
// #72821# copy dynamic defaults
pTargetShell->GetDoc()->ReplaceDefaults( *pSourceShell->GetDoc());
diff --git a/sw/source/uibase/dochdl/swdtflvr.cxx b/sw/source/uibase/dochdl/swdtflvr.cxx
index fe1c4ed9ea42..18f79a541729 100644
--- a/sw/source/uibase/dochdl/swdtflvr.cxx
+++ b/sw/source/uibase/dochdl/swdtflvr.cxx
@@ -370,7 +370,7 @@ namespace
{
const SwDoc &rSrc = *rSrcWrtShell.GetDoc();
- rDest.ReplaceCompatabilityOptions(rSrc);
+ rDest.ReplaceCompatibilityOptions(rSrc);
rDest.ReplaceDefaults(rSrc);
//It would probably make most sense here to only insert the styles used
diff --git a/writerfilter/source/dmapper/PropertyMap.cxx b/writerfilter/source/dmapper/PropertyMap.cxx
index b28638e04851..90c7fd0564b2 100644
--- a/writerfilter/source/dmapper/PropertyMap.cxx
+++ b/writerfilter/source/dmapper/PropertyMap.cxx
@@ -773,7 +773,7 @@ uno::Reference< text::XTextColumns > SectionPropertyMap::ApplyColumnProperties(
rPropNameSupplier.GetName( PROP_SEPARATOR_LINE_IS_ON ),
uno::makeAny( m_bSeparatorLineIsOn ));
xColumnContainer->setPropertyValue( sTextColumns, uno::makeAny( xColumns ) );
- // Set the columns to be unbalanced if that compatability option is set or this is the last section.
+ // Set the columns to be unbalanced if that compatibility option is set or this is the last section.
if (rDM_Impl.GetSettingsTable()->GetNoColumnBalance() || rDM_Impl.GetIsLastSectionGroup())
xColumnContainer->setPropertyValue("DontBalanceTextColumns", uno::makeAny(true));
}
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index c072fd100fc4..60d1ce5bcb09 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -898,8 +898,8 @@ public:
// Replace all property defaults with those from rSource.
void ReplaceDefaults( const SwDoc& rSource );
- // Replace all compatability options with those from rSource.
- void ReplaceCompatabilityOptions( const SwDoc& rSource );
+ // Replace all compatibility options with those from rSource.
+ void ReplaceCompatibilityOptions( const SwDoc& rSource );
/** Replace all user defined document properties with xSourceDocProps.
diff --git a/sw/source/filter/ww8/ww8scan.hxx b/sw/source/filter/ww8/ww8scan.hxx
index 893df81c07a0..95ed4281d303 100644
--- a/sw/source/filter/ww8/ww8scan.hxx
+++ b/sw/source/filter/ww8/ww8scan.hxx
@@ -1548,7 +1548,7 @@ public:
bool fWriteReservation : 1;
bool fLockRev : 1; // when 1, the current revision marking state is locked
bool fEmbedFonts : 1; // when 1, document contains embedded True Type fonts
- // compatability options
+ // compatibility options
bool copts_fNoTabForInd : 1; // when 1, don't add automatic tab stops for hanging indent
bool copts_fNoSpaceRaiseLower : 1; // when 1, don't add extra space for raised or lowered characters
bool copts_fSupressSpbfAfterPgBrk : 1; // when 1, supress the paragraph Space Before and Space After options after a page break
@@ -1604,7 +1604,7 @@ public:
/*
bei nFib >= 103 gehts weiter:
*/
- bool fNoTabForInd : 1; // see above in compatability options
+ bool fNoTabForInd : 1; // see above in compatibility options
bool fNoSpaceRaiseLower : 1; // see above
bool fSupressSpbfAfterPageBreak : 1; // see above
bool fWrapTrailSpaces : 1; // see above
@@ -1616,26 +1616,26 @@ public:
bool fTransparentMetafiles : 1; // see above
bool fShowBreaksInFrames : 1; // see above
bool fSwapBordersFacingPgs : 1; // see above
- bool fCompatabilityOptions_Unknown1_13 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_13 : 1; // #i78591#
bool fExpShRtn : 1; // #i78591# and #i56856#
- bool fCompatabilityOptions_Unknown1_15 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_16 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_15 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_16 : 1; // #i78591#
bool fSuppressTopSpacingMac5 : 1; // Suppress extra line spacing at top
// of page like MacWord 5.x
bool fTruncDxaExpand : 1; // Expand/Condense by whole number of points
bool fPrintBodyBeforeHdr : 1; // Print body text before header/footer
bool fNoLeading : 1; // Don't add extra spacebetween rows of text
- bool fCompatabilityOptions_Unknown1_21 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_21 : 1; // #i78591#
bool fMWSmallCaps : 1; // Use larger small caps like MacWord 5.x
- bool fCompatabilityOptions_Unknown1_23 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_24 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_25 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_26 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_27 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_28 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_29 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_30 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown1_31 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_23 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_24 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_25 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_26 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_27 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_28 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_29 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_30 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown1_31 : 1; // #i78591#
bool fUsePrinterMetrics : 1; //The magic option
// hier sollte bei nFib <= 105 Schluss sein, sonst ist Datei fehlerhaft!
@@ -1675,38 +1675,38 @@ public:
sal_Int16 hpsZoonFontPag;
sal_Int16 dywDispPag;
- bool fCompatabilityOptions_Unknown2_1 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_2 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_1 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_2 : 1; // #i78591#
bool fDontUseHTMLAutoSpacing : 1;
- bool fCompatabilityOptions_Unknown2_4 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_5 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_6 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_7 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_8 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_9 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_10 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_11 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_12 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_13 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_14 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_15 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_16 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_17 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_18 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_19 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_20 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_21 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_22 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_23 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_24 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_25 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_26 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_27 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_28 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_29 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_30 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_31 : 1; // #i78591#
- bool fCompatabilityOptions_Unknown2_32 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_4 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_5 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_6 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_7 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_8 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_9 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_10 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_11 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_12 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_13 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_14 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_15 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_16 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_17 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_18 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_19 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_20 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_21 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_22 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_23 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_24 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_25 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_26 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_27 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_28 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_29 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_30 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_31 : 1; // #i78591#
+ bool fCompatibilityOptions_Unknown2_32 : 1; // #i78591#
sal_uInt16 fUnknown3 : 15;
bool fUseBackGroundInAllmodes : 1;
@@ -1735,11 +1735,11 @@ public:
WW8Dop();
bool Write(SvStream& rStrm, WW8Fib& rFib) const;
- sal_uInt32 GetCompatabilityOptions() const;
- void SetCompatabilityOptions(sal_uInt32 a32Bit);
+ sal_uInt32 GetCompatibilityOptions() const;
+ void SetCompatibilityOptions(sal_uInt32 a32Bit);
// i#78591#
- sal_uInt32 GetCompatabilityOptions2() const;
- void SetCompatabilityOptions2(sal_uInt32 a32Bit);
+ sal_uInt32 GetCompatibilityOptions2() const;
+ void SetCompatibilityOptions2(sal_uInt32 a32Bit);
};
class WW8PLCF_HdFt